@@ -16,7 +16,7 @@
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KStandardAction>
+#include <KStandardActions>
 
 #include <bcodec/bdecoder.h>
 #include <bcodec/bencoder.h>
@@ -66,10 +66,10 @@ void SearchActivity::setupActions()
     connect(search_action, &QAction::triggered, this, qOverload<>(&SearchActivity::search));
     ac->addAction(QStringLiteral("search_tab_search"), search_action);
 
-    find_action = KStandardAction::find(this, &SearchActivity::find, this);
+    find_action = KStandardActions::find(this, &SearchActivity::find, this);
     ac->addAction(QStringLiteral("search_tab_find"), find_action);
 
-    home_action = KStandardAction::home(this, &SearchActivity::home, this);
+    home_action = KStandardActions::home(this, &SearchActivity::home, this);
     ac->addAction(QStringLiteral("search_home"), home_action);
 }
 
@@ -137,10 +137,10 @@ void SearchActivity::loadCurrentSearches()
             if (!dict)
                 continue;
 
-            QString text = dict->getString("TEXT", nullptr);
-            QString sbtext = dict->getString("SBTEXT", nullptr);
+            QString text = dict->getString("TEXT");
+            QString sbtext = dict->getString("SBTEXT");
             int engine = dict->getInt("ENGINE");
-            QUrl url = QUrl(dict->getString("URL", nullptr));
+            QUrl url = QUrl(dict->getString("URL"));
 
             SearchWidget *search = newSearchWidget(text);
             search->restore(url, text, sbtext, engine);
